@@ -14,8 +14,6 @@
 # limitations under the License.
 #
 """
-A kernel's features for efficient sampling, used by
-:class:`gpflux.sampling.KernelWithFeatureDecomposition`
+Basis functions.
 """
-
-from gpflux.layers.basis_functions.random_fourier_features import RandomFourierFeatures
+from gpflux.layers.basis_functions import fourier_features
